@@ -100,7 +100,10 @@ def filter_json(request, model_str, field):
 
 
 def m2m_list_view(request, model_str):
-    pks = [int(pk) for pk in request.GET.get("q", "").split(",")]
+    try:
+        pks = [int(pk) for pk in request.GET.get("q", "").split(",")]
+    except ValueError:
+        pks = ()
     Model = get_model(model_str)
     objs = Model.objects.filter(pk__in=pks)
 
@@ -115,4 +118,4 @@ def m2m_remove_view(request, model_str):
 
     return render(request, "large_data_admin/m2m/remove.html", {
         "objs": objs,
-    })
\ No newline at end of file
+    })
